Array(data, dtype, locn)
########################

.. doxygenfunction:: librapid::Array::Array(double val, Datatype dtype = Datatype::INT64, Accelerator locn = Accelerator::CPU)
.. doxygenfunction:: librapid::Array::Array(const std::vector<V> &values, Datatype dtype = Datatype::NONE, Accelerator locn = Accelerator::CPU)
